@@ -1,7 +1,10 @@
-package any::feature;
 use 5.008;
 use strict;
 use warnings;
+
+package any::feature;
+# ABSTRACT: Backwards-compatible handling of new syntactic features
+
 use Perl::Version;
 use Carp qw(croak);
 use UNIVERSAL::require;
@@ -11,7 +14,7 @@ BEGIN {
         require mysubs;
     }
 }
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 my %dispatch = (
     activate => {
         say => {
@@ -102,12 +105,19 @@ sub unimport {
     }
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 any::feature - Backwards-compatible handling of new syntactic features
 
+=head1 VERSION
+
+version 1.100840
+
 =head1 SYNOPSIS
 
     use any::feature 'say';
@@ -171,79 +181,77 @@ The features are lexically scoped, which is how they work in Perl 5.10:
     }
     say 'bar';     # dies at compile-time
 
-=head1 SUBROUTINES
+=head1 FUNCTIONS
 
-=over 4
-
-=item C<dispatch>
+=head2 dispatch
 
 Takes as arguments a direction (C<activate> or C<deactivate>), a package name
 and a feature name. Activates or deactivates the given feature for the given
 package.
 
-=item C<activate>
+=head2 activate
 
 Takes as arguments a package name and a feature name. Uses C<dispatch()> to
 activate the given feature in the given package.
 
-=item C<deactivate>
+=head2 deactivate
 
 Takes as arguments a package name and a feature name. Uses C<dispatch()> to
 deactivate the given feature in the given package.
 
-=item C<import>
+=head2 import
 
 Takes the same arguments as Perl 5.10's C<use feature> pragma. Uses
 C<activate()> and C<deactivate()> to do its job.
 
-=item C<unimport>
+=head2 unimport
 
 Takes the same arguments as Perl 5.10's C<no feature> pragma. Uses
 C<activate()> and C<deactivate()> to do its job.
 
-=item C<get_effective_version>
+=head2 get_effective_version
 
 Uses L<Perl::Version> to get the version number of the current perl
 interpreter.  This is used to decide the course of action.
 
-=item C<get_effective_revision>
+=head2 get_effective_revision
 
 Uses L<Perl::Version> to get the revision number of the current perl
 interpreter.  This is used to decide the course of action.
 
-=back
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=any-feature>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/any-feature/>.
+site near you, or see
+L<http://search.cpan.org/dist/any-feature/>.
 
-The development version lives at L<http://github.com/hanekomu/any-feature/>.
+The development version lives at
+L<http://github.com/hanekomu/any-feature/>.
 Instead of sending patches, please fork this project using the standard git
 and github infrastructure.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Marcel GrE<uuml>nauer
+This software is copyright (c) 2009 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
